From: Richard W.M. Jones <rjones@redhat.com>
Date: Thu, 24 Nov 2011 16:27:36 +0000 (+0000)
Subject: debian: Use mdadm -D --export instead of mdadm -DY.
X-Git-Tag: 1.15.6~5
X-Git-Url: http://git.annexia.org/?a=commitdiff_plain;h=2d5841133a199619d56d026ad9ea4e97791f4a8f;p=libguestfs.git

debian: Use mdadm -D --export instead of mdadm -DY.

For compatibility with mdadm on Debian Squeeze.
---

diff --git a/daemon/md.c b/daemon/md.c
index 43bb64e..5a4d815 100644
--- a/daemon/md.c
+++ b/daemon/md.c
@@ -243,7 +243,7 @@ do_md_detail(const char *md)
   char **ret = NULL;
   int size = 0, alloc = 0;
 
-  const char *mdadm[] = { "mdadm", "-DY", md, NULL };
+  const char *mdadm[] = { "mdadm", "-D", "--export", md, NULL };
   r = commandv(&out, &err, mdadm);
   if (r == -1) {
     reply_with_error("%s", err);
@@ -257,7 +257,7 @@ do_md_detail(const char *md)
     goto error;
   }
 
   /* Parse the output of mdadm -DY:
    * MD_LEVEL=raid1
    * MD_DEVICES=2
    * MD_METADATA=1.0
@@ -257,7 +257,7 @@ do_md_detail(const char *md)
   }
 
-  /* Parse the output of mdadm -DY:
+  /* Parse the output of mdadm -D --export:
    * MD_LEVEL=raid1
    * MD_DEVICES=2